@@ -7,7 +7,8 @@
 #include "config.h"
 #include "adw-action-row.h"
 
-#include "adw-macros-private.h"
+#include "adw-marshalers.h"
+#include "adw-widget-utils-private.h"
 
 /**
  * AdwActionRow:
@@ -46,8 +47,6 @@
  *
  * It contains subnodes `label.title` and `label.subtitle` representing
  * respectively the title label and subtitle label.
- *
- * Since: 1.0
  */
 
 typedef struct
@@ -64,6 +63,7 @@ typedef struct
 
   int title_lines;
   int subtitle_lines;
+  gboolean subtitle_selectable;
   GtkWidget *activatable_widget;
   GBinding *activatable_binding;
 } AdwActionRowPrivate;
@@ -84,6 +84,7 @@ enum {
   PROP_ACTIVATABLE_WIDGET,
   PROP_TITLE_LINES,
   PROP_SUBTITLE_LINES,
+  PROP_SUBTITLE_SELECTABLE,
   LAST_PROP,
 };
 
@@ -154,6 +155,9 @@ adw_action_row_get_property (GObject    *object,
   case PROP_TITLE_LINES:
     g_value_set_int (value, adw_action_row_get_title_lines (self));
     break;
+  case PROP_SUBTITLE_SELECTABLE:
+    g_value_set_boolean (value, adw_action_row_get_subtitle_selectable (self));
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -183,6 +187,9 @@ adw_action_row_set_property (GObject      *object,
   case PROP_TITLE_LINES:
     adw_action_row_set_title_lines (self, g_value_get_int (value));
     break;
+  case PROP_SUBTITLE_SELECTABLE:
+    adw_action_row_set_subtitle_selectable (self, g_value_get_boolean (value));
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -234,8 +241,6 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    *
    * The subtitle is interpreted as Pango markup unless
    * [property@PreferencesRow:use-markup] is set to `FALSE`.
-   *
-   * Since: 1.0
    */
   props[PROP_SUBTITLE] =
     g_param_spec_string ("subtitle", NULL, NULL,
@@ -247,7 +252,7 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    *
    * The icon name for this row.
    *
-   * Since: 1.0
+   * Deprecated: 1.3: Use [method@ActionRow.add_prefix] to add an icon.
    */
   props[PROP_ICON_NAME] =
     g_param_spec_string ("icon-name", NULL, NULL,
@@ -260,14 +265,12 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * The widget to activate when the row is activated.
    *
    * The row can be activated either by clicking on it, calling
-   * [method@ActionRow.activate], or via mnemonics in the title or the subtitle.
+   * [method@ActionRow.activate], or via mnemonics in the title.
    * See the [property@PreferencesRow:use-underline] property to enable
    * mnemonics.
    *
    * The target widget will be activated by emitting the
    * [signal@Gtk.Widget::mnemonic-activate] signal on it.
-   *
-   * Since: 1.0
    */
   props[PROP_ACTIVATABLE_WIDGET] =
     g_param_spec_object ("activatable-widget", NULL, NULL,
@@ -280,8 +283,6 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * The number of lines at the end of which the title label will be ellipsized.
    *
    * If the value is 0, the number of lines won't be limited.
-   *
-   * Since: 1.0
    */
   props[PROP_TITLE_LINES] =
     g_param_spec_int ("title-lines", NULL, NULL,
@@ -296,8 +297,6 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * ellipsized.
    *
    * If the value is 0, the number of lines won't be limited.
-   *
-   * Since: 1.0
    */
   props[PROP_SUBTITLE_LINES] =
     g_param_spec_int ("subtitle-lines", NULL, NULL,
@@ -305,23 +304,39 @@ adw_action_row_class_init (AdwActionRowClass *klass)
                       0,
                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
+  /**
+   * AdwActionRow:subtitle-selectable: (attributes org.gtk.Property.get=adw_action_row_get_subtitle_selectable org.gtk.Property.set=adw_action_row_set_subtitle_selectable)
+   *
+   * Whether the user can copy the subtitle from the label.
+   *
+   * See also [property@Gtk.Label:selectable].
+   *
+   * Since: 1.3
+   */
+  props[PROP_SUBTITLE_SELECTABLE] =
+    g_param_spec_boolean ("subtitle-selectable", NULL, NULL,
+                          FALSE,
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
   /**
    * AdwActionRow::activated:
    *
    * This signal is emitted after the row has been activated.
-   *
-   * Since: 1.0
    */
   signals[SIGNAL_ACTIVATED] =
     g_signal_new ("activated",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
                   0,
-                  NULL, NULL, NULL,
+                  NULL, NULL,
+                  adw_marshal_VOID__VOID,
                   G_TYPE_NONE,
                   0);
+  g_signal_set_va_marshaller (signals[SIGNAL_ACTIVATED],
+                              G_TYPE_FROM_CLASS (klass),
+                              adw_marshal_VOID__VOIDv);
 
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/Adwaita/ui/adw-action-row.ui");
@@ -377,8 +392,6 @@ adw_action_row_buildable_init (GtkBuildableIface *iface)
  * Creates a new `AdwActionRow`.
  *
  * Returns: the newly created `AdwActionRow`
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_action_row_new (void)
@@ -392,8 +405,6 @@ adw_action_row_new (void)
  * @widget: a widget
  *
  * Adds a prefix widget to @self.
- *
- * Since: 1.0
  */
 void
 adw_action_row_add_prefix (AdwActionRow *self,
@@ -407,7 +418,7 @@ adw_action_row_add_prefix (AdwActionRow *self,
   priv = adw_action_row_get_instance_private (self);
 
   gtk_box_prepend (priv->prefixes, widget);
-  gtk_widget_show (GTK_WIDGET (priv->prefixes));
+  gtk_widget_set_visible (GTK_WIDGET (priv->prefixes), TRUE);
 }
 
 /**
@@ -416,8 +427,6 @@ adw_action_row_add_prefix (AdwActionRow *self,
  * @widget: a widget
  *
  * Adds a suffix widget to @self.
- *
- * Since: 1.0
  */
 void
 adw_action_row_add_suffix (AdwActionRow *self,
@@ -431,7 +440,7 @@ adw_action_row_add_suffix (AdwActionRow *self,
   priv = adw_action_row_get_instance_private (self);
 
   gtk_box_append (priv->suffixes, widget);
-  gtk_widget_show (GTK_WIDGET (priv->suffixes));
+  gtk_widget_set_visible (GTK_WIDGET (priv->suffixes), TRUE);
 }
 
 /**
@@ -440,8 +449,6 @@ adw_action_row_add_suffix (AdwActionRow *self,
  * @widget: the child to be removed
  *
  * Removes a child from @self.
- *
- * Since: 1.0
  */
 void
 adw_action_row_remove (AdwActionRow *self,
@@ -473,8 +480,6 @@ adw_action_row_remove (AdwActionRow *self,
  * Gets the subtitle for @self.
  *
  * Returns: (nullable): the subtitle for @self
- *
- * Since: 1.0
  */
 const char *
 adw_action_row_get_subtitle (AdwActionRow *self)
@@ -497,8 +502,6 @@ adw_action_row_get_subtitle (AdwActionRow *self)
  *
  * The subtitle is interpreted as Pango markup unless
  * [property@PreferencesRow:use-markup] is set to `FALSE`.
- *
- * Since: 1.0
  */
 void
 adw_action_row_set_subtitle (AdwActionRow *self,
@@ -526,7 +529,7 @@ adw_action_row_set_subtitle (AdwActionRow *self,
  *
  * Returns: (nullable): the icon name for @self
  *
- * Since: 1.0
+ * Deprecated: 1.3: Use [method@ActionRow.add_prefix] to add an icon.
  */
 const char *
 adw_action_row_get_icon_name (AdwActionRow *self)
@@ -547,7 +550,7 @@ adw_action_row_get_icon_name (AdwActionRow *self)
  *
  * Sets the icon name for @self.
  *
- * Since: 1.0
+ * Deprecated: 1.3: Use [method@ActionRow.add_prefix] to add an icon.
  */
 void
 adw_action_row_set_icon_name (AdwActionRow *self,
@@ -576,8 +579,6 @@ adw_action_row_set_icon_name (AdwActionRow *self,
  * Gets the widget activated when @self is activated.
  *
  * Returns: (nullable) (transfer none): the activatable widget for @self
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_action_row_get_activatable_widget (AdwActionRow *self)
@@ -612,13 +613,11 @@ activatable_widget_weak_notify (gpointer  data,
  * Sets the widget to activate when @self is activated.
  *
  * The row can be activated either by clicking on it, calling
- * [method@ActionRow.activate], or via mnemonics in the title or the subtitle.
+ * [method@ActionRow.activate], or via mnemonics in the title.
  * See the [property@PreferencesRow:use-underline] property to enable mnemonics.
  *
  * The target widget will be activated by emitting the
  * [signal@Gtk.Widget::mnemonic-activate] signal on it.
- *
- * Since: 1.0
  */
 void
 adw_action_row_set_activatable_widget (AdwActionRow *self,
@@ -677,8 +676,6 @@ adw_action_row_set_activatable_widget (AdwActionRow *self,
  *
  * Returns: the number of lines at the end of which the title label will be
  *   ellipsized
- *
- * Since: 1.0
  */
 int
 adw_action_row_get_title_lines (AdwActionRow *self)
@@ -701,8 +698,6 @@ adw_action_row_get_title_lines (AdwActionRow *self)
  * ellipsized.
  *
  * If the value is 0, the number of lines won't be limited.
- *
- * Since: 1.0
  */
 void
 adw_action_row_set_title_lines (AdwActionRow *self,
@@ -735,8 +730,6 @@ adw_action_row_set_title_lines (AdwActionRow *self,
  *
  * Returns: the number of lines at the end of which the subtitle label will be
  *   ellipsized
- *
- * Since: 1.0
  */
 int
 adw_action_row_get_subtitle_lines (AdwActionRow *self)
@@ -759,8 +752,6 @@ adw_action_row_get_subtitle_lines (AdwActionRow *self)
  * ellipsized.
  *
  * If the value is 0, the number of lines won't be limited.
- *
- * Since: 1.0
  */
 void
 adw_action_row_set_subtitle_lines (AdwActionRow *self,
@@ -784,13 +775,60 @@ adw_action_row_set_subtitle_lines (AdwActionRow *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SUBTITLE_LINES]);
 }
 
+/**
+ * adw_action_row_get_subtitle_selectable: (attributes org.gtk.Method.get_property=subtitle-selectable)
+ * @self: a `AdwActionRow`
+ *
+ * Gets whether the user can copy the subtitle from the label
+ *
+ * Returns: whether the user can copy the subtitle from the label
+ *
+ * Since: 1.3
+ */
+gboolean
+adw_action_row_get_subtitle_selectable (AdwActionRow *self)
+{
+  AdwActionRowPrivate *priv = adw_action_row_get_instance_private (self);
+
+  g_return_val_if_fail (ADW_IS_ACTION_ROW (self), FALSE);
+
+  return priv->subtitle_selectable;
+}
+
+/**
+ * adw_action_row_set_subtitle_selectable: (attributes org.gtk.Method.set_property=subtitle-selectable)
+ * @self: a `AdwActionRow`
+ * @subtitle_selectable: `TRUE` if the user can copy the subtitle from the label
+ *
+ * Sets whether the user can copy the subtitle from the label
+ *
+ * See also [property@Gtk.Label:selectable].
+ *
+ * Since: 1.3
+ */
+void
+adw_action_row_set_subtitle_selectable (AdwActionRow *self,
+                                        gboolean      subtitle_selectable)
+{
+  AdwActionRowPrivate *priv = adw_action_row_get_instance_private (self);
+
+  g_return_if_fail (ADW_IS_ACTION_ROW (self));
+
+  subtitle_selectable = !!subtitle_selectable;
+
+  if (priv->subtitle_selectable == subtitle_selectable)
+    return;
+
+  priv->subtitle_selectable = subtitle_selectable;
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SUBTITLE_SELECTABLE]);
+}
+
 /**
  * adw_action_row_activate:
  * @self: an action row
  *
  * Activates @self.
- *
- * Since: 1.0
  */
 void
 adw_action_row_activate (AdwActionRow *self)
